module Pod
  # Subclass of Pod::Source to provide support for RSYNC Specs repositories
  #
  class RsyncSource < Source
    def parse_config
        @url, @argv = File.open(repo + '.rsync_config', "r:UTF-8", &:read).split("\n").map { |c| c.strip }
        @url + "/" unless @url.end_with?("/")
        @argv ||= "" unless @argv
        if File.exist?(repo + '.skip')
          @skip = "true"
        else
          @skip = "false"
        end

    end

    def save_config
      File.open(repo+".rsync_config", "w:UTF-8") do |f|
        f.write "#{@url}\n#{@argv}"
      end
    end

    def url
      parse_config unless @url
      @url
    end

    def url=(url)
      @url = url
    end

    def skip
      parse_config unless @skip
      @skip
    end

    def skip=(skip)
      @skip = skip
    end

    def argv
      parse_config unless @argv
      @argv
    end

    def argv=(argv)
      @argv = argv
    end

    def self.rsync_repo?(dir)
      (dir+".rsync_config").exist?
    end

    def self.rsync_sources
      if Pod::Config.instance.repos_dir.exist?
        dirs = Pod::Config.instance.repos_dir.children.select(&:directory?)
        dirs = dirs.select do |dir|
          RsyncSource.rsync_repo?(dir)
        end
        dirs.map { |dir| RsyncSource.new(dir) }
      else
        []
      end
    end

    def self.rsync_source_by_url(url)
      print "url::: #{url}"
      rsync_sources.find do |source|
        source.url == url
      end
    end
  end
end
